[SCM] WebKit Debian packaging branch, debian/unstable, updated. debian/1.1.15-1-40151-g37bb677

cblu cblu at 268f45cc-cd09-0410-ab3c-d52691b4dbfc
Sat Sep 26 07:06:07 UTC 2009


The following commit has been merged in the debian/unstable branch:
commit 80c08365e9a2bb4625974dcbc819168c1745be93
Author: cblu <cblu at 268f45cc-cd09-0410-ab3c-d52691b4dbfc>
Date:   Fri Nov 22 00:13:44 2002 +0000

    	Fixed: 3009881 - plugins get mouse-overs even when mouse is in menus
    	Fixed: 3108240 - Loading datasource sometimes doesn't have cancelled error when cancelled
    
            * Plugins.subproj/WebBaseNetscapePluginView.m:
            (-[WebBaseNetscapePluginView sendNullEvent]): check if menus are showing
            (-[WebBaseNetscapePluginView restartNullEvents]): tweak
            * WebView.subproj/WebDataSourcePrivate.m:
            (-[WebDataSource _stopLoading]): set cancelled error if main handle is gone
    
    
    git-svn-id: http://svn.webkit.org/repository/webkit/trunk@2808 268f45cc-cd09-0410-ab3c-d52691b4dbfc

diff --git a/WebKit/ChangeLog b/WebKit/ChangeLog
index 5413418..fa83881 100644
--- a/WebKit/ChangeLog
+++ b/WebKit/ChangeLog
@@ -1,3 +1,14 @@
+2002-11-21  Chris Blumenberg  <cblu at apple.com>
+
+	Fixed: 3009881 - plugins get mouse-overs even when mouse is in menus
+	Fixed: 3108240 - Loading datasource sometimes doesn't have cancelled error when cancelled
+
+        * Plugins.subproj/WebBaseNetscapePluginView.m:
+        (-[WebBaseNetscapePluginView sendNullEvent]): check if menus are showing
+        (-[WebBaseNetscapePluginView restartNullEvents]): tweak
+        * WebView.subproj/WebDataSourcePrivate.m:
+        (-[WebDataSource _stopLoading]): set cancelled error if main handle is gone
+
 === Alexander-33 ===
 
 2002-11-20  Darin Adler  <darin at apple.com>
diff --git a/WebKit/ChangeLog-2002-12-03 b/WebKit/ChangeLog-2002-12-03
index 5413418..fa83881 100644
--- a/WebKit/ChangeLog-2002-12-03
+++ b/WebKit/ChangeLog-2002-12-03
@@ -1,3 +1,14 @@
+2002-11-21  Chris Blumenberg  <cblu at apple.com>
+
+	Fixed: 3009881 - plugins get mouse-overs even when mouse is in menus
+	Fixed: 3108240 - Loading datasource sometimes doesn't have cancelled error when cancelled
+
+        * Plugins.subproj/WebBaseNetscapePluginView.m:
+        (-[WebBaseNetscapePluginView sendNullEvent]): check if menus are showing
+        (-[WebBaseNetscapePluginView restartNullEvents]): tweak
+        * WebView.subproj/WebDataSourcePrivate.m:
+        (-[WebDataSource _stopLoading]): set cancelled error if main handle is gone
+
 === Alexander-33 ===
 
 2002-11-20  Darin Adler  <darin at apple.com>
diff --git a/WebKit/WebView.subproj/WebDataSourcePrivate.m b/WebKit/WebView.subproj/WebDataSourcePrivate.m
index b688148..3cb2bbf 100644
--- a/WebKit/WebView.subproj/WebDataSourcePrivate.m
+++ b/WebKit/WebView.subproj/WebDataSourcePrivate.m
@@ -202,8 +202,17 @@
     }
 
     _private->stopping = YES;
-    
-    [_private->mainClient cancel];
+
+    if(_private->mainClient){
+        // Stop the main handle and let it set the cancelled error.
+        [_private->mainClient cancel];
+    }else{
+        // Main handle is already done. Set the cancelled error.
+        WebError *cancelledError = [WebError errorWithCode:WebErrorCodeCancelled
+                                                  inDomain:WebErrorDomainWebFoundation
+                                                failingURL:[[self URL] absoluteString]];
+        [self _setMainDocumentError:cancelledError];
+    }
     
     NSArray *clients = [_private->subresourceClients copy];
     [clients makeObjectsPerformSelector:@selector(cancel)];

diff --git a/WebKit/Plugins.subproj/WebBaseNetscapePluginView.m b/WebKit/Plugins.subproj/WebBaseNetscapePluginView.m
index fce326e..27c0f4f 100644
--- a/WebKit/Plugins.subproj/WebBaseNetscapePluginView.m
+++ b/WebKit/Plugins.subproj/WebBaseNetscapePluginView.m
@@ -164,11 +164,14 @@
 
     [self getCarbonEvent:&event];
 
-    // plug-in should not react to cursor position when not active.
-    // FIXME: How does passing a v and h of 0 prevent it from reacting to the cursor position?
-    if (![_window isKeyWindow]) {
-        event.where.v = 0;
-        event.where.h = 0;
+    // Plug-in should not react to cursor position when not active or when a menu is down.
+    MenuTrackingData trackingData;
+    OSStatus error = GetMenuTrackingData(NULL, &trackingData);
+    
+    if (![_window isKeyWindow] || (error == noErr && trackingData.menu)){
+        // FIXME: How does passing a v and h of 0 prevent it from reacting to the cursor position?
+        event.where.v = -1;
+        event.where.h = -1;
     }
 
     [self sendEvent:&event];
@@ -189,7 +192,7 @@
 
     NSTimeInterval interval;
     
-    if ([_window isKeyWindow]) {
+    if ([_window isKeyWindow]){
         interval = NullEventIntervalActive;
     }else{
         interval = NullEventIntervalNotActive;
-- 
WebKit Debian packaging



More information about the Pkg-webkit-commits mailing list